@@ -1,10 +1,13 @@
 # -*- coding: utf-8 -*-
 # adding client side aggregation
 #    name="yokr",
-#    version="0.3.02"
-#    2021-0-29 changed flush_cache(forceUpload=True)  to allow one upload of 
+#    version="0.3.04"
+#    2021-05-13 added forceUpload parameter to clean_env(forceUpload=True)
+#    version="0.3.03"
+#    2021-04-29 changed flush_cache(forceUpload=True)  to allow one upload of 
 #              data without data withou waiting a minimal time since 
 #              last regular upload
+
 import builtins
 import datetime
 import functools
@@ -1539,10 +1542,10 @@ def flush_cache(forceUpload=True):
         logger.error("exception in yokr - flush_cache() : %s", err)
 
 
-def clean_env():
+def clean_env(forceUpload=True):
     """cleans and restarts yokr internal environment and cache"""
     try:
-        flush_cache()
+        flush_cache(forceUpload=forceUpload)
         _reloadConfigFiles()
         _ykrCreateCollectorDBIfNeeded(dbPathAndName22=_yCE.dbPathAndName22)
     except Exception as err:
